import {
    DateRange, Form, Modal, ModalService, Select, SelectMultiple, SelectTreeMultiple, Tabs,
} from '@zeedhi/common';
import { IDictionary, Metadata } from '@zeedhi/core';
import { TekGrid, TekTreeGrid } from '@zeedhi/teknisa-components-common';

export class Sm00004101RelatorioCustomizavelContratoController {
    private ModalFiltro!: Modal;

    private campoModal?: IDictionary;

    private filtroTabItens?: IDictionary;

    public fecharModal() {
        this.ModalFiltro.hide();
    }

    public destruirModal() {
        this.ModalFiltro?.destroy();
    }

    public setFilterContrato({ component }: any) {
        component.datasource.setFilter({
            IDATIVO: 'S',
        });
    }

    public async abrirModal() {
        if (!this.ModalFiltro) {
            this.ModalFiltro = await ModalService.createFromJson('sm_00004_101_relatorio_customizavel_contrato/modal/sm_00004_101_filtro_relatorio_contrato', true);
        }
        await this.ModalFiltro.show();

        setTimeout(() => {
            Metadata.getInstance<SelectMultiple>('form-dados-contrato_modelo-contrato').value = this.campoModal?.nrseqmodcontra || null;
            Metadata.getInstance<SelectMultiple>('form-dados-contrato_contrato').value = this.campoModal?.nrseqcontrato || null;
            Metadata.getInstance<SelectMultiple>('form-dados-contrato_parceiro-negocio').value = this.campoModal?.nrseqorcamento || null;
            Metadata.getInstance<Select>('form-dados-contrato_ativo').value = this.campoModal?.nrparcnegocio || null;
            Metadata.getInstance<SelectMultiple>('form-dados-contrato_situacao').value = this.campoModal?.idativo || null;
            Metadata.getInstance<SelectMultiple>('form-dados-contrato_filiar').value = this.campoModal?.idsituacaocontrato || null;
            Metadata.getInstance<Number>('form-dados-contrato_versao').valueOf = this.campoModal?.nrversaocontrato || null;
            Metadata.getInstance<SelectMultiple>('form-dados-contrato_centro-custo').value = this.campoModal?.cdfilial || null;
            Metadata.getInstance<DateRange>('form-validade_data-inicial').value = this.campoModal?.cdcentcusto || null;
            Metadata.getInstance<DateRange>('form-validade_data-final').value = this.campoModal?.dtiniciocontrato || null;
            Metadata.getInstance<DateRange>('form-validade_data-inicial-vigente').value = this.campoModal?.dtfimcontrato || null;
            Metadata.getInstance<DateRange>('form-validade_data-inicial-final').value = this.campoModal?.dtinicontrato || null;
            Metadata.getInstance<SelectMultiple>('form-dados-proposta-proposta').value = this.campoModal?.dtfincontrato || null;
            Metadata.getInstance<Select>('form-dados-proposta-modelo-proposta').value = this.campoModal?.nrorcamentomodelo || null;
            Metadata.getInstance<Select>('form-dados-proposta-escopo-faturamento').value = this.campoModal?.nrtipoorcamento || null;
            Metadata.getInstance<Select>('form-dados-contrato_operador-responsavel').value = this.campoModal?.cdoperresponsavel || null;
            Metadata.getInstance<Select>('form-dados-servico-CDSERVORCA').value = this.campoModal?.cdservorca || null;
            Metadata.getInstance<Select>('form-dados-servico-IDELEMENTO').value = this.campoModal?.idelemento || null;
            Metadata.getInstance<Select>('form-dados-servico-CDTPMEDIDASERV').value = this.campoModal?.cdtpmedidaserv || null;
            Metadata.getInstance<DateRange>('form-rescisao-data').value = this.campoModal?.dtrecisaocontr || null;
            Metadata.getInstance<DateRange>('form-paralisado-motivo').value = this.campoModal?.nrmotivoparalisacao || null;
            Metadata.getInstance<DateRange>('form-paralisado-responsavel').value = this.campoModal?.nrmotivoparalisacao || null;
            Metadata.getInstance<DateRange>('form-paralisado-data').value = this.campoModal?.nrmotivoparalisacao || null;
        }, 2000);
    }

    public eventFilter({ event }: any) {
        event.preventDefault();
        this.abrirModal();
    }

    public expandirGruposFiltro({ component }: any) {
        const form = Metadata.getInstance<Form>(component.name.split('_')[1]);
        form.isVisible = !form.isVisible;

        component.iconName = (component.iconName === 'mdi-chevron-down') ? 'mdi-chevron-right' : 'mdi-chevron-down';
    }

    public limparCampos() {
        Metadata.getInstance<Form>('form-dados-contrato').clearForm();
        Metadata.getInstance<Form>('form-validade').clearForm();
        Metadata.getInstance<Form>('form-dados-proposta').clearForm();
        Metadata.getInstance<Form>('form-dados-servico').clearForm();
        Metadata.getInstance<Form>('form-dados-servico').clearForm();

        this.campoModal = {
            nrseqmodcontra: null,
            nrseqcontrato: null,
            nrseqorcamento: null,
            nrparcnegocio: null,
            idativo: null,
            idsituacaocontrato: null,
            nrversaocontrato: null,
            cdfilial: null,
            cdcentcusto: null,
            dtiniciocontrato: null,
            dtfimcontrato: null,
            dtinicontrato: null,
            dtfincontrato: null,
            nrorcamentomodelo: null,
            nrtipoorcamento: null,
            cdoperresponsavel: null,
            cdservorca: null,
            idelemento: null,
            cdtpmedidaserv: null,
            dtrecisaocontr: null,
            nrmotivoparalisacao: null,
            paraoperador: null,
            paradata: null,
        };

        this.filtroTabItens = {
            NRSEQCONTRATO: null,
            NRPARCNEGOCIO: null,
            CDSERVORCA: null,
            IDELEMENTO: null,
        };
    }

    public filterGridsRelatorioContrato() {
        const gridProposta = Metadata.getInstance<TekGrid>('grid-tab-contratos');

        this.campoModal = {
            nrseqmodcontra: Metadata.getInstance<SelectMultiple>('form-dados-contrato_modelo-contrato').value,
            nrseqcontrato: Metadata.getInstance<SelectMultiple>('form-dados-contrato_contrato').value,
            nrparcnegocio: Metadata.getInstance<SelectMultiple>('form-dados-contrato_parceiro-negocio').value,
            idativo: Metadata.getInstance<Select>('form-dados-contrato_ativo').value,
            idsituacaocontrato: Metadata.getInstance<SelectMultiple>('form-dados-contrato_situacao').value,
            cdfilial: Metadata.getInstance<SelectMultiple>('form-dados-contrato_filiar').value,
            nrversaocontrato: Metadata.getInstance<Number>('form-dados-contrato_versao').valueOf,
            cdcentcusto: Metadata.getInstance<SelectMultiple>('form-dados-contrato_centro-custo').value,
            dtiniciocontrato: Metadata.getInstance<DateRange>('form-validade_data-inicial').value,
            dtfimcontrato: Metadata.getInstance<DateRange>('form-validade_data-final').value,
            dtinicontrato: Metadata.getInstance<DateRange>('form-validade_data-inicial-vigente').value,
            dtfincontrato: Metadata.getInstance<DateRange>('form-validade_data-inicial-final').value,
            nrseqorcamento: Metadata.getInstance<SelectMultiple>('form-dados-proposta-proposta').value,
            nrorcamentomodelo: Metadata.getInstance<Select>('form-dados-proposta-modelo-proposta').value,
            nrtipoorcamento: Metadata.getInstance<Select>('form-dados-proposta-escopo-faturamento').value,
            cdoperresponsavel: Metadata.getInstance<Select>('form-dados-contrato_operador-responsavel').value,
            cdservorca: Metadata.getInstance<Select>('form-dados-servico-CDSERVORCA').value,
            idelemento: Metadata.getInstance<SelectTreeMultiple>('form-dados-servico-IDELEMENTO').value,
            cdtpmedidaserv: Metadata.getInstance<SelectMultiple>('form-dados-servico-CDTPMEDIDASERV').value,
            nrmotivoparalisacao: Metadata.getInstance<DateRange>('form-paralisado-motivo').value,
            paraoperador: Metadata.getInstance<DateRange>('form-paralisado-responsavel').value,
            paradata: Metadata.getInstance<DateRange>('form-paralisado-data').value,
        };

        gridProposta.datasource.setFilter({
            NRSEQMODCONTRA: this.campoModal.nrseqmodcontra,
            NRSEQCONTRATO: this.campoModal.nrseqcontrato,
            NRSEQORCAMENTO: this.campoModal.nrseqorcamento,
            NRPARCNEGOCIO: this.campoModal.nrparcnegocio,
            IDATIVO: this.campoModal.idativo,
            IDSITUACAOCONTRATO: this.campoModal.idsituacaocontrato,
            NRVERSAOCONTRATO: this.campoModal.nrversaocontrato,
            CDFILIAL: this.campoModal.cdfilial,
            CDCENTCUST: this.campoModal.cdcentcusto,
            DTINICIOCONTRATO: this.campoModal.dtiniciocontrato,
            DTFIMCONTRATO: this.campoModal.dtfimcontrato,
            DTINICONTRATO: this.campoModal.dtinicontrato,
            DTFINCONTRATO: this.campoModal.dtfincontrato,
            NRORCAMENTOMODELO: this.campoModal.nrorcamentomodelo,
            NRTIPOORCAMENTO: this.campoModal.nrtipoorcamento,
            CDOPERRESPONSAVEL: this.campoModal.cdoperresponsavel,
            CDSERVORCA: this.campoModal.cdservorca,
            IDELEMENTO: this.campoModal.idelemento,
            CDTPMEDIDASERV: this.campoModal.cdtpmedidaserv,
            DTRECISAOCONTR: this.campoModal.dtrecisaocontr,
            NRMOTIVOPARALISACAO: this.campoModal.nrmotivoparalisacao,
            PARAOPERADOR: this.campoModal.paraoperador,
            PARADATA: this.campoModal.paradata,
        });

        this.filtroTabItens = {
            NRSEQCONTRATO: this.campoModal.nrseqcontrato,
            NRPARCNEGOCIO: this.campoModal.nrparcnegocio,
            CDSERVORCA: this.campoModal.cdservorca,
            IDELEMENTO: this.campoModal.idelemento,
            CDTPMEDIDASERV: this.campoModal.cdtpmedidaserv,
        };

        this.fecharModal();
    }

    public filtrarTabItens() {
        const tab = Metadata.getInstance<Tabs>('tab-relatorios-contrato');

        if (tab.tabs[tab.activeTab].name === 'tab-itens') {
            if (this.filtroTabItens !== undefined) {
                if (this.filtroTabItens?.NRSEQCONTRATO.length !== 0 || this.filtroTabItens?.NRPARCNEGOCIO.length !== 0
                    || this.filtroTabItens?.CDSERVORCA.length !== 0 || this.filtroTabItens?.CDTPMEDIDASERV.length !== 0 || this.filtroTabItens?.IDELEMENTO !== null) {
                    setTimeout(() => {
                        const gridItens = Metadata.getInstance<TekTreeGrid>('tek-grid-tab-itens');
                        gridItens.datasource.setFilter({
                            NRSEQCONTRATO: this.filtroTabItens?.NRSEQCONTRATO,
                            NRPARCNEGOCIO: this.filtroTabItens?.NRPARCNEGOCIO,
                            CDSERVORCA: this.filtroTabItens?.CDSERVORCA,
                            IDELEMENTO: this.filtroTabItens?.IDELEMENTO,
                            CDTPMEDIDASERV: this.filtroTabItens?.CDTPMEDIDASERV,
                        });
                    }, 1000);
                }
            }
        }
    }
}
